==> cscec5b-dataexchange-api-3.0.0-20210601.034557-80-sources.jar: com/ejianc/business/dataexchange/hystrix/InvHystrix.java <==
package com.ejianc.business.dataexchange.hystrix;

import com.ejianc.business.dataexchange.api.IInvApi;
import com.ejianc.business.dataexchange.vo.Invbas;
import com.ejianc.business.dataexchange.vo.Invcl;
import com.ejianc.business.dataexchange.vo.Invman;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 模块hystrix
 *
 * @author brin
 *
 */
@Component
public class InvHystrix implements IInvApi {

	@Override
	public CommonResponse<List<Invcl>> queryNCInvclByTs(@RequestParam(required = true) String ts) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invbas>> queryNCInvbasByTs(@RequestParam(required = true) String ts) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invbas>> queryNCInvbasByQj(@RequestParam(required = false) String beginTime, @RequestParam(required = false) String endTime,
														  @RequestParam(required = false) Integer beginRow, @RequestParam(required = false) Integer endRow) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invman>> queryNCInvmanByTs(@RequestParam(required = true) String ts, @RequestParam(required = false) String pkCorp) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invman>> queryNCInvmanByQj(@RequestParam(required = false) String beginTime, @RequestParam(required = false) String endTime,
														  @RequestParam(required = false) Integer beginRow, @RequestParam(required = false) Integer endRow, @RequestParam(required = false) String pkCorp) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

}

==> cscec5b-dataexchange-api-3.0.1-20230523.093300-79-sources.jar: com/ejianc/business/dataexchange/hystrix/InvHystrix.java <==
package com.ejianc.business.dataexchange.hystrix;

import com.ejianc.business.dataexchange.api.IInvApi;
import com.ejianc.business.dataexchange.vo.Invbas;
import com.ejianc.business.dataexchange.vo.Invcl;
import com.ejianc.business.dataexchange.vo.Invman;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.stereotype.Component;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * 模块hystrix
 *
 * @author brin
 *
 */
@Component
public class InvHystrix implements IInvApi {

	@Override
	public CommonResponse<List<Invcl>> queryNCInvclByTs(@RequestParam(required = true) String ts) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invbas>> queryNCInvbasByTs(@RequestParam(required = true) String ts) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invbas>> queryNCInvbasByQj(@RequestParam(required = false) String beginTime, @RequestParam(required = false) String endTime,
														  @RequestParam(required = false) Integer beginRow, @RequestParam(required = false) Integer endRow) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invman>> queryNCInvmanByTs(@RequestParam(required = true) String ts, @RequestParam(required = false) String pkCorp) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<List<Invman>> queryNCInvmanByQj(@RequestParam(required = false) String beginTime, @RequestParam(required = false) String endTime,
														  @RequestParam(required = false) Integer beginRow, @RequestParam(required = false) Integer endRow, @RequestParam(required = false) String pkCorp) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

	@Override
	public CommonResponse<String> redisByOrgList(@RequestParam(required = false) String beginTime, @RequestParam(required = false) String endTime, @RequestParam(required = false) String tenantId, @RequestParam(required = false) String pkCorp) {
		return CommonResponse.error("网络问题， 查询失败。");
	}

}
